%bcond_with llvm

%define rel	1

%define major		0
%define libname		%mklibname %{name} %{major}
%define develname	%mklibname %{name} -d

%define date		%nil
%if 0%{date}
%define release		%mkrel 1.git%{date}.%{rel}
%define tarballver	%{commit}
%define tarballdir	%{commit}
%define tarballgit	+git%{date}
%define commit		2b594466b43e9a7ae7739f3bf24f03c1de289769
%else
%define release		%mkrel %{rel}
%define tarballver	%{version}
%define tarballdir	%{version}
%endif

Name:		lightspark
Version:	0.8.7
Release:	%{release}
Summary:	An alternative Flash Player implementation
Group:		Networking/WWW
License:	LGPLv3+
URL:		https://lightspark.github.io/
Source0:	https://github.com/lightspark/%{name}/archive/%{tarballdir}/%{name}-%{version}%{?tarballgit}.tar.gz
## Upstream patches

# Mageia patches

ExclusiveArch:	%{ix86} x86_64

BuildRequires:	cmake
BuildRequires:	nasm
BuildRequires:	boost-devel
BuildRequires:	ffmpeg-devel
%if %{with llvm}
BuildRequires:	llvm-devel >= 3.9.1
%endif
BuildRequires:	pkgconfig(glew)
BuildRequires:	pkgconfig(ftgl)
BuildRequires:	pkgconfig(sdl2)
BuildRequires:	pkgconfig(SDL2_mixer)
BuildRequires:	pkgconfig(gtkglext-1.0)
BuildRequires:	pkgconfig(fontconfig)
BuildRequires:	pkgconfig(libjpeg)
BuildRequires:	pkgconfig(libcurl)
BuildRequires:	pkgconfig(libxml++-2.6)
BuildRequires:	pkgconfig(librtmp)
BuildRequires:	pkgconfig(liblzma)

Requires:	fonts-ttf-liberation
Obsoletes:	lightspark-pulse < 0.7.2-23

%description
Lightspark is a modern, free, open-source flash player implementation.

Lightspark features:

* JIT compilation of Actionscript to native x86 bytecode using LLVM
* Hardware accelerated rendering using OpenGL Shaders (GLSL)
* Very good and robust support for current-generation Actionscript 3
* A new, clean, code base exploiting Multi-Threading and optimized for
  modern hardware. Designed from scratch after the official Flash
  documentation was released.

%package -n	%{libname}
Summary:	%{name} libraries
Group:		System/Libraries

%description -n	%{libname}
This is the libraries used by %{name}.

%package -n	%{develname}
Summary:	Development libraries for %{name}
Group:		Development/C++
Provides:	%{name}-devel = %{version}-%{release}
Requires:	%{libname} = %{version}-%{release}

%description -n	%{develname}
Development files for the %{name} libraries.

%package	mozilla-plugin
Summary:	Mozilla compatible plugin for %{name}
Group:		Networking/WWW
Conflicts:	gnash-firefox-plugin

%description	mozilla-plugin
This is the Mozilla compatible plugin for %{name}.

%package	ppapi-plugin
Summary:	PPAPI compatible plugin for %{name}
Group:		Networking/WWW

%description	ppapi-plugin
This is the PPAPI compatible plugin for %{name}.


%prep
%setup -q -n %{name}-%{tarballver}
%autopatch -p1

%build
%cmake \
	-Wno-dev \
%if %{with llvm}
	-DENABLE_LLVM=TRUE \
%endif
	-DPPAPI_PLUGIN_DIRECTORY=%{_libdir}/%{name}/PepperFlash
%cmake_build

%install
%cmake_install

#(eandry) tell lightspark where the libs are
install -d -m 0755  %{buildroot}%{_sysconfdir}/ld.so.conf.d
echo "%{_libdir}/lightspark" > %{buildroot}%{_sysconfdir}/ld.so.conf.d/lightspark-%{__isa_bits}.conf

%files
%doc ChangeLog CONTRIBUTING CONTRIBUTORS README.md
%license COPYING COPYING.LESSER
%config(noreplace) %{_sysconfdir}/xdg/lightspark.conf
%{_bindir}/%{name}
%{_datadir}/applications/%{name}.desktop
%{_iconsdir}/hicolor/*/apps/%{name}.*
%{_mandir}/man1/%{name}.1.*

%files -n %{libname}
%config %{_sysconfdir}/ld.so.conf.d/lightspark-%{__isa_bits}.conf
%{_libdir}/%{name}/lib%{name}.so.%{major}{,.*}

%files -n %{develname}
%{_libdir}/%{name}/lib%{name}.so

%files mozilla-plugin
%{_libdir}/mozilla/plugins/lib%{name}plugin.so

%files ppapi-plugin
%{_libdir}/%{name}/PepperFlash/


%changelog
* Mon May 29 2023 daviddavid <daviddavid> 0.8.7-1.mga9
+ Revision: 1959636
- new version: 0.8.7

* Sun Apr 16 2023 daviddavid <daviddavid> 0.8.6.1-2.mga9
+ Revision: 1953262
- remove no more needed old pcre-devel build dependency

* Wed Nov 16 2022 daviddavid <daviddavid> 0.8.6.1-1.mga9
+ Revision: 1908166
- new version: 0.8.6.1
+ tv <tv>
- Rebuild for llvm-15
- Rebuild for llvm-14
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild
+ mrambo3501 <mrambo3501>
- rebuild for ffmpeg 5.0

* Thu Oct 21 2021 tv <tv> 0.8.5-2.mga9
+ Revision: 1752503
- Rebuild for llvm 13.0

* Tue Aug 10 2021 luigiwalser <luigiwalser> 0.8.5-1.mga9
+ Revision: 1741017
- 0.8.5

* Tue Aug 10 2021 luigiwalser <luigiwalser> 0.8.4.1-2.git20210418.2.mga9
+ Revision: 1740959
+ rebuild (emptylog)

* Thu Apr 22 2021 daviddavid <daviddavid> 0.8.4.1-2.git20210418.1.mga9
+ Revision: 1717931
- update to latest git snapshot: 0.8.4.1-git20210418 (mga#28502)

* Tue Mar 02 2021 daviddavid <daviddavid> 0.8.4.1-1.mga9
+ Revision: 1695851
- new version: 0.8.4.1

* Mon Mar 01 2021 tv <tv> 0.8.3-4.mga9
+ Revision: 1695181
- rebuild for llvm-12

* Wed Dec 02 2020 luigiwalser <luigiwalser> 0.8.3-3.mga8
+ Revision: 1651355
- rebuild for glew

* Thu Nov 26 2020 tv <tv> 0.8.3-2.mga8
+ Revision: 1649609
- rebuild for llvm

* Sun Jul 05 2020 daviddavid <daviddavid> 0.8.3-1.mga8
+ Revision: 1602329
- new version: 0.8.3
- remove merged upstream patch

* Sun May 03 2020 wally <wally> 0.8.2-5.mga8
+ Revision: 1578080
- rebuild for boost 1.73.0

* Mon Apr 06 2020 daviddavid <daviddavid> 0.8.2-4.mga8
+ Revision: 1565046
- disable llvm support (https://github.com/lightspark/lightspark/issues/475)
+ tv <tv>
- Try to workaround cmake failing to detect llvm headers
- rebuild with llvm 10

* Mon Jan 27 2020 wally <wally> 0.8.2-3.mga8
+ Revision: 1484088
- rebuild for boost 1.72.0
- build with new cmake macros

* Thu Sep 26 2019 daviddavid <daviddavid> 0.8.2-2.mga8
+ Revision: 1446244
- new version: 0.8.2
+ tv <tv>
- rebuild for new llvm

* Mon Apr 15 2019 daviddavid <daviddavid> 0.8.1-4.mga7
+ Revision: 1390752
- rebuild for new llvm/clang 8.0

* Tue Oct 16 2018 wally <wally> 0.8.1-3.mga7
+ Revision: 1321062
- rebuild for new boost 1.68.0

* Sun Oct 07 2018 daviddavid <daviddavid> 0.8.1-2.mga7
+ Revision: 1318536
- add two upstream patches to fix compilation with llvm 7
+ tv <tv>
- rebuild for llvm 7.0

* Sat Jun 02 2018 daviddavid <daviddavid> 0.8.1-1.mga7
+ Revision: 1233650
- new version: 0.8.1
- remove merged upstream patches

* Sat Apr 28 2018 daviddavid <daviddavid> 0.8.0-10.mga7
+ Revision: 1223073
- rebuild for new ffmpeg 4.0

* Thu Apr 12 2018 tv <tv> 0.8.0-9.mga7
+ Revision: 1217695
- rebuild with llvm-6

* Mon Dec 25 2017 wally <wally> 0.8.0-7.mga7
+ Revision: 1184683
- rebuild for new boost

* Sun Dec 03 2017 daviddavid <daviddavid> 0.8.0-6.mga7
+ Revision: 1180798
- rebuild for new glew 2.1.0

* Tue Nov 21 2017 tv <tv> 0.8.0-5.mga7
+ Revision: 1178119
- rebuild for boost 1.65

* Sat Nov 11 2017 daviddavid <daviddavid> 0.8.0-4.mga7
+ Revision: 1176876
- add upstream patch to fix build with llvm 5.0
+ tv <tv>
- rebuild with llvm-5

* Thu Sep 21 2017 tv <tv> 0.8.0-3.mga7
+ Revision: 1156933
- rebuild with llvm-4.0 in core/release

* Sat Sep 16 2017 tv <tv> 0.8.0-2.mga7
+ Revision: 1154691
- rebuild with latest boost

* Sun Jul 23 2017 daviddavid <daviddavid> 0.8.0-1.mga7
+ Revision: 1129302
- new version: 0.8.0
- switch to SDL2/SDL2_mixer
- add the PPAPI subpackage
- remove the pulseaudio dependency

* Tue May 02 2017 akien <akien> 0.7.2-22.git20160929.4.mga6
+ Revision: 1098300
- Rebuild for ffmpeg 3.3

* Wed Mar 08 2017 akien <akien> 0.7.2-22.git20160929.3.mga6
+ Revision: 1089876
- Rebuild for ffmpeg 3.2.4

* Sat Jan 07 2017 tmb <tmb> 0.7.2-22.git20160929.2.mga6
+ Revision: 1080482
- rebuild with new llvm

* Sun Oct 30 2016 daviddavid <daviddavid> 0.7.2-22.git20160929.1.mga6
+ Revision: 1064159
- new snapshot: 0.7.2-git20160929
  * commit: c5a14bbc5947d290925768483da017877ad7d34c

* Sun May 15 2016 daviddavid <daviddavid> 0.7.2-22.git20160515.1.mga6
+ Revision: 1015824
- new snapshot: 0.7.2-git20160515 (fixes build against llvm 3.8)
  * commit: f311ba2201574b5d6983e35d08f467c803acab1f
  * https://github.com/lightspark/lightspark/issues/263
+ tv <tv>
- rebuild for new llvm

* Thu Jan 14 2016 daviddavid <daviddavid> 0.7.2-22.git20160111.1.mga6
+ Revision: 922974
- new snapshot release: 0.7.2-git20160111
  * commit: 9e5f3db11e53a1126c32720dda3f5ac7733083de

* Wed Jan 06 2016 tmb <tmb> 0.7.2-22.git20151129.3.mga6
+ Revision: 920083
- rebuild for new llvm

* Fri Dec 25 2015 daviddavid <daviddavid> 0.7.2-22.git20151129.2.mga6
+ Revision: 914608
- rebuild for new boost 1.60.0

* Sun Dec 06 2015 daviddavid <daviddavid> 0.7.2-22.git20151129.1.mga6
+ Revision: 908562
- new snapshot release: 0.7.2-git20151129
  * commit: bdd71ed269190fdc1b401cfe32623db9090eb157

* Fri Oct 16 2015 daviddavid <daviddavid> 0.7.2-22.git20151010.1.mga6
+ Revision: 892247
- new snapshot release: 0.7.2-git20151010
  * commit: 3cfa146c62ca81bf1c0abfd4d226715adce785fe

* Fri Sep 25 2015 daviddavid <daviddavid> 0.7.2-22.git20150823.3.mga6
+ Revision: 883475
- rebuild for new boost 1.59.0
- introduce license macro

* Wed Sep 23 2015 daviddavid <daviddavid> 0.7.2-22.git20150823.2.mga6
+ Revision: 882400
- Patch0: fix build with latest llvm 3.7.0 (from OpenSUSE)
- rebuild for new llvm 3.7.0
- use date instead of commit for release tag and for tarball

* Sat Aug 29 2015 daviddavid <daviddavid> 0.7.2-22.git87e38d5.1.mga6
+ Revision: 870871
- increase release to fix incorrect release tag

* Sat Aug 29 2015 daviddavid <daviddavid> 0.7.2-22.git87e38d5.0.1.mga6
+ Revision: 870866
- new snapshot release: 0.7.2-git87e38d55fbf6f818cf77c1019efffa5909c5f2fc
- update URL and Source URL
- remove merged upstream patches
- update cmake options
- rebuild for new boost-1.58.0 and new llvm-3.6.2

* Wed Jun 24 2015 akien <akien> 0.7.2-20.mga6
+ Revision: 842016
- Rebuild for GLEW 1.12

* Fri Nov 14 2014 akien <akien> 0.7.2-19.mga5
+ Revision: 797114
- Rebuild for ffmpeg 2.4

* Wed Oct 15 2014 fwang <fwang> 0.7.2-18.mga5
+ Revision: 749251
- more fix
- update header file location
- try support llvm 3.5 from upstream git
- rebuild for new llvm
+ umeabot <umeabot>
- Second Mageia 5 Mass Rebuild
- Mageia 5 Mass Rebuild
+ tmb <tmb>
- rebuild for new llwm
+ tv <tv>
- rebuild for missing pythoneggs deps
- s/uggests:/Recommends:/

* Mon Sep 01 2014 luigiwalser <luigiwalser> 0.7.2-13.mga5
+ Revision: 670270
- rebuild for glew

* Sat Jul 05 2014 pterjan <pterjan> 0.7.2-12.mga5
+ Revision: 643915
- Rebuild for new llvm

* Sat May 24 2014 tv <tv> 0.7.2-11.mga5
+ Revision: 625631
- rebuild for new llvm

* Sun Mar 16 2014 fwang <fwang> 0.7.2-10.mga5
+ Revision: 604185
- adopt to new path of freetype

* Sun Mar 16 2014 fwang <fwang> 0.7.2-9.mga5
+ Revision: 604177
- fix build with llvm 3.4
+ luigiwalser <luigiwalser>
- rebuild for librtmp

* Sat Feb 08 2014 barjac <barjac> 0.7.2-8.mga5
+ Revision: 586731
- rebuild against boost-1.55

* Fri Jan 10 2014 pterjan <pterjan> 0.7.2-7.mga4
+ Revision: 566139
- Fix Buildequires

* Sat Oct 19 2013 umeabot <umeabot> 0.7.2-6.mga4
+ Revision: 532692
- Mageia 4 Mass Rebuild

* Thu Aug 22 2013 fwang <fwang> 0.7.2-5.mga4
+ Revision: 469248
- add upstream patch to build with llvm 3.3
+ tv <tv>
- rebuild with new LLVM

* Wed Jul 24 2013 sander85 <sander85> 0.7.2-4.mga4
+ Revision: 457711
- Rebuild for new glew

* Mon Jul 15 2013 fwang <fwang> 0.7.2-3.mga4
+ Revision: 454506
- more patch
- more patch on recent ffmpeg
- update define
- rebuild for new ffmpeg

* Mon Jul 08 2013 fwang <fwang> 0.7.2-2.mga4
+ Revision: 451254
- rebuild for new boost

* Mon Jun 24 2013 fwang <fwang> 0.7.2-1.mga4
+ Revision: 446157
- new version 0.7.2

* Mon Jun 03 2013 tv <tv> 0.7.0-6.mga4
+ Revision: 436308
- rebuild for new libpng

* Wed Apr 10 2013 malo <malo> 0.7.0-5.mga3
+ Revision: 409469
- rebuild for boost 1.53

* Sat Jan 12 2013 fwang <fwang> 0.7.0-4.mga3
+ Revision: 358913
- fix build with llvm 3.2 (patch from gentoo)
+ umeabot <umeabot>
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Thu Dec 20 2012 fwang <fwang> 0.7.0-3.mga3
+ Revision: 332954
- rebuild for new boost

* Sat Dec 01 2012 fwang <fwang> 0.7.0-2.mga3
+ Revision: 323653
- rebuild for new pcre

* Mon Oct 29 2012 tv <tv> 0.7.0-1.mga3
+ Revision: 311464
- new release
- new release

* Sun Sep 16 2012 tv <tv> 0.6.0.1-4.mga3
+ Revision: 294518
- BR librtmp-devel

* Thu Aug 30 2012 fwang <fwang> 0.6.0.1-3.mga3
+ Revision: 285669
- rebuild for new glew

* Tue Jul 31 2012 fwang <fwang> 0.6.0.1-2.mga3
+ Revision: 276568
- rebuild for new glew

* Wed Jun 13 2012 tv <tv> 0.6.0.1-1.mga3
+ Revision: 260379
- new release
- drop patch 0 (merged)
- new release

* Fri Jun 01 2012 fwang <fwang> 0.5.7-1.mga3
+ Revision: 252627
- add upstream patch to build with ffmpeg 0.11
- new version 0.5.7
+ kamil <kamil>
- rebuild against new boost 1.49.0 and ffmpeg 0.11.2

* Thu Apr 12 2012 blino <blino> 0.5.4.1-2.mga2
+ Revision: 230505
- buildrequire llvm-devel since package has been split
+ fwang <fwang>
- drop merged patches
- new version 0.5.4.1

* Sat Jan 07 2012 wally <wally> 0.5.3-1.mga2
+ Revision: 192934
- add P1 to fix build with new llvm3
- add P2, P3 and P4 to fix linking
- use .desktop file provided by upstream
- add major check to file list
- fix filename in ld.so.conf.d to allow installing 32bit lib pkg to 64 bit machine
+ fwang <fwang>
- new version 0.5.3

* Mon Nov 28 2011 fwang <fwang> 0.5.1-3.mga2
+ Revision: 173624
- fix build with latest glib
- rebuild for new boost

* Mon Oct 03 2011 fwang <fwang> 0.5.1-2.mga2
+ Revision: 151160
- rebuild for new glew

* Sun Oct 02 2011 fwang <fwang> 0.5.1-1.mga2
+ Revision: 150833
- br jpeg
- new version 0.5.1
- rebuild
- 0.5 final

* Thu Jul 14 2011 fwang <fwang> 0.5.0-0.rc1.1.mga2
+ Revision: 123888
- fix build with latest ffmpeg
- new version 0.5.0 rc1

* Sun Jun 26 2011 fwang <fwang> 0.4.8.1-1.mga2
+ Revision: 113877
- new version 0.4.8.1
- new version 0.4.8

* Fri Apr 01 2011 ahmad <ahmad> 0.4.6.1-1.mga1
+ Revision: 79444
- bump libxml++2.6-devel BR version again, it requires 2.33.1
+ tv <tv>
- relax BR on libxml++
- new release
+ eandry <eandry>
- bump BR version
- New version 0.4.6

* Thu Mar 03 2011 eandry <eandry> 0.4.5.3-1.mga1
+ Revision: 63447
- New version 0.4.5.3

* Sun Feb 20 2011 eandry <eandry> 0.4.5.2-1.mga1
+ Revision: 54716
- remove buildroot and old conditional
- imported package lightspark


* Tue Dec 28 2010 Thierry Vignaud <tv@mandriva.org> 0.4.5.1-2mdv2011.0
+ Revision: 625582
- fix BR on 2010.x due to 2010.1/2010.2 trick

* Sun Dec 26 2010 Funda Wang <fwang@mandriva.org> 0.4.5.1-1mdv2011.0
+ Revision: 625188
- update file list

  + Thierry Vignaud <tv@mandriva.org>
    - new release

* Sun Sep 26 2010 Funda Wang <fwang@mandriva.org> 0.4.4.3-2mdv2011.0
+ Revision: 581106
- update file list
- BR xml++
- drop conflict files

  + Thierry Vignaud <tv@mandriva.org>
    - BR libxml2-devel
    - new release
    - fix BR for 2010.1

* Mon Sep 13 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.4.2-2mdv2011.0
+ Revision: 578076
- also suggest pulse plugin for mozilla plugins?\195

* Mon Sep 13 2010 Funda Wang <fwang@mandriva.org> 0.4.4.2-1mdv2011.0
+ Revision: 577850
- BR boost

  + Emmanuel Andry <eandry@mandriva.org>
    - New version 0.4.4.2
    - create pulse subpackage

* Sat Sep 04 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.4.1-1mdv2011.0
+ Revision: 575943
- don't use cmake macro, breaks build
- New version 0.4.4.1
- upstream fixed build with --no-undefined

* Wed Sep 01 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.4-2mdv2011.0
+ Revision: 575169
- package libification
- add ldconfig conf file to tell lightspark where libs are

* Mon Aug 30 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.4-1mdv2011.0
+ Revision: 574519
- set define _disable_ld_no_undefined to 1
- requires fonts-ttf-liberation

  + Thierry Vignaud <tv@mandriva.org>
    - disable patch 0
    - new release

* Sat Aug 14 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.3-7mdv2011.0
+ Revision: 569760
- drop useless p0
- add patch from gentoo to respect cmake linking flags
- drop gnash BR and specify gnash path in cmake
- set BUILD_TYPE to Release

* Fri Aug 13 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.3-6mdv2011.0
+ Revision: 569445
- drop unneeded ffi5-devel BR
- fix libraries location

* Fri Aug 13 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.3-5mdv2011.0
+ Revision: 569422
- gnash seems to be needed at build time

* Fri Aug 13 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.3-4mdv2011.0
+ Revision: 569403
- bump release
- BR ffi5-devel
- conflicts with gnash-firefox-plugin, firefox can't handle different plugins for same mimetype (upstream recommendation)

* Thu Aug 12 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.3-2mdv2011.0
+ Revision: 569282
- drop requires on mozilla and gnash (better with suggest)

* Thu Aug 12 2010 Emmanuel Andry <eandry@mandriva.org> 0.4.3-1mdv2011.0
+ Revision: 569250
- New version 0.4.3
- rediff p0
- suggests gnash for AVM1 fallback

* Thu Jul 29 2010 Funda Wang <fwang@mandriva.org> 0.4.2.2-1mdv2011.0
+ Revision: 562914
- drop unused section
- import lightspark


